@@ -4,7 +4,7 @@
 
 #include <boost/noncopyable.hpp>
 #include <boost/shared_ptr.hpp>
-#include "sqlite3.h"
+#include "sqlite3-cpp.h"
 #include "DbColumnDataType.h"
 
 class DbConnection;
@@ -35,6 +35,7 @@ private:
   List params_;
   int group_, groups_;
   std::vector<DATA_TYPE> types_;
+  bool with_alt_types_;
 
 public:
   SqliteResultImpl(const DbConnectionPtr& conn_, const std::string& sql);
@@ -46,7 +47,8 @@ private:
   void init(bool params_have_rows);
 
 public:
-  bool complete();
+  void close();
+  bool complete() const;
   int n_rows_fetched();
   int n_rows_affected();
   void bind(const List& params);
