@@ -1,13 +1,6 @@
 default_skip <-
   c(
-    # enable to test a particular test only
-    # "(?!data_timestamp_current).*",
-
-    # sql
-    "roundtrip_date",                             # #109
-    "roundtrip_timestamp",                        # #110
-
-    "column_info_consistent",                     # https://github.com/r-dbi/DBItest/issues/181
+    if (packageVersion("DBItest") < "1.7.1.9004") "column_info_consistent",                     # https://github.com/r-dbi/DBItest/issues/181
 
     NULL
   )
@@ -17,6 +10,7 @@ if (packageVersion("DBItest") >= "1.6.0") {
     SQLite(),
     list(dbname = tempfile("DBItest", fileext = ".sqlite")),
     tweaks = DBItest::tweaks(
+      dbitest_version = "1.7.2",
       constructor_relax_args = TRUE,
       placeholder_pattern = c("?", "$1", "$name", ":name"),
       date_cast = function(x) paste0("'", x, "'"),
